/*
 * Copyright (c) 2008-2012, Hazel Bilisim Ltd. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.cluster;

import com.hazelcast.nio.Address;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

public class MemberRemover extends AbstractRemotelyProcessable {
    private Address deadAddress = null;

    public MemberRemover() {
    }

    public MemberRemover(Address deadAddress) {
        super();
        this.deadAddress = deadAddress;
    }

    public void process() {
        if (conn != null) {
            Address endpoint = conn.getEndPoint();
            if (endpoint != null && endpoint.equals(getNode().getMasterAddress())) {
                getNode().clusterManager.doRemoveAddress(deadAddress);
            }
        }
    }

    public void readData(DataInput in) throws IOException {
        super.readData(in);
        deadAddress = new Address();
        deadAddress.readData(in);
    }

    public void writeData(DataOutput out) throws IOException {
        super.writeData(out);
        deadAddress.writeData(out);
    }
}
